@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.25';
+$VERSION = '5.26';
 
 =head1 NAME
 
@@ -124,7 +124,7 @@ sub MetaSearch {
         if($hash{'order'} eq 'createdate') {
             @res = map {$res{$_}} sort {int($res{$a}->{createdate}) <=> int($res{$b}->{createdate})} keys %res;
         } else {
-            @res = map {$res{$_}} sort {$res{$a}->{$hash{'order'}} <=>$res{$b}->{$hash{'order'}}} keys %res;
+            @res = map {$res{$_}} sort {$res{$a}->{$hash{'order'}} cmp $res{$b}->{$hash{'order'}}} keys %res;
         }
     } else {
         @res = map {$res{$_}} keys %res;
